<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Tchat</translation>
    </message>
    <message>
        <source>Antistring</source>
        <translation>Antistring</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Général</translation>
    </message>
    <message>
        <source>Enable Antistring</source>
        <translation>Activer Antistring</translation>
    </message>
    <message>
        <source>Block message</source>
        <translation>Bloquer le message</translation>
    </message>
    <message>
        <source>Admonition</source>
        <translation>Admonition</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Journal</translation>
    </message>
    <message>
        <source>Write log to file</source>
        <translation>Enregistrer le journal dans un fichier</translation>
    </message>
    <message>
        <source>Conditions</source>
        <translation>Conditions</translation>
    </message>
    <message>
        <source>Antistring notifications</source>
        <translation>Notifications Antistring</translation>
    </message>
</context>
<context>
    <name>AntistringConfigurationUiHandler</name>
    <message>
        <source>Condition</source>
        <translation>Condition</translation>
    </message>
    <message>
        <source>Don&apos;t use</source>
        <translation>Ne pas utiliser</translation>
    </message>
    <message>
        <source>Factor</source>
        <translation>Facteur</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Ajoutez</translation>
    </message>
    <message>
        <source>Change</source>
        <translation>Changez</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
</context>
<context>
    <name>AntistringMessageFilter</name>
    <message>
        <source>     DATA AND TIME      ::   ID   ::    MESSAGE
</source>
        <translation>     DONNÉES ET TEMPS      ::   ID   ::    MESSAGE
</translation>
    </message>
</context>
<context>
    <name>AntistringNotificationService</name>
    <message>
        <source>Antistring</source>
        <translation>Antistring</translation>
    </message>
    <message>
        <source>Your interlocutor send you love letter</source>
        <translation>Votre interlocuteur vous a envoyé une lettre d&apos;amour</translation>
    </message>
</context>
</TS>